diff --git a/.travis.yml b/.travis.yml
index cbd288daa57f47f4b0bcb0603752ff8e11063af8..a623f2539fa9364e6207c618a77e74fecf7bc579 100644
--- a/.travis.yml
+++ b/.travis.yml
@@ -169,7 +169,6 @@ notifications:
   slack:
     rooms:
       - piwik:3HWhNh21qPfDACQXTrJOb0mW
-      - piwikpro:7OABSbDrywSTo2nv9lD2svXG
     on_success: :change
     on_failure: :change
 
diff --git a/README.md b/README.md
index 0f09b3ce0fc762691d483a87287a805355a5724b..6e49eebf48b9575fcf80f77b1881bdf7dd922895 100644
--- a/README.md
+++ b/README.md
@@ -58,20 +58,17 @@ If you do not have a server, consider our Piwik Hosting partner: http://piwik.or
 
 For the list of all tickets closed in the current and past releases, see http://piwik.org/changelog/. For the list of technical changes in the Piwik platform, see [http://developer.piwik.org/changelog](http://developer.piwik.org/changelog).
 
-## Participate!
+## Get involved!
 
 We believe in liberating Web Analytics, providing a free platform for simple and advanced analytics. Piwik was built by dozens of people like you,
-and we need your help to make Piwik better… Why not participate in a useful project today?
-
-You will find pointers on how you can participate in Piwik at http://piwik.org/get-involved/
+and we need your help to make Piwik better… Why not participate in a useful project today? [Learn how you can contribute to Piwik.](https://piwik.org/get-involved)
 
 ## Quality Assurance
 
-The Piwik project uses an ever-expanding comprehensive set of thousands of unit tests and hundreds of automated integration tests, system tests, JavaScript tests, and screenshot UI tests, running on a continuous integration server as part of its software quality assurance.
+The Piwik project uses an ever-expanding comprehensive set of thousands of unit tests and hundreds of automated integration tests, system tests, JavaScript tests, and screenshot UI tests, running on a continuous integration server as part of its software quality assurance. [Learn more](https://piwik.org/qa/)
 
 We use [BrowserStack.com](https://www.browserstack.com/) testing tool to help check the Piwik user interface is compatible with many browsers.
 
-[Learn more](https://piwik.org/qa/)
 
 ## Security
 
@@ -79,14 +76,20 @@ Security is a top priority at Piwik. As potential issues are discovered, we vali
 
 [Learn more](https://piwik.org/security/)
 
+## Support for Piwik
+
+For **Free support**, post a message in our community forums: [forum.piwik.org](http://forum.piwik.org/)
+
+For **Professional paid support**, send a message to our network of Piwik professionals: [piwik.org/support](http://piwik.org/contact/)  
 
 ## Contact
 
-http://piwik.org
+Website: [piwik.org](https://piwik.org)
+
+About us: [piwik.org/team/](https://piwik.org/team/)
 
-Contact us: http://piwik.org/contact/ or hello@piwik.org
+Contact us: [piwik.org/contact/](https://piwik.org/contact/)
 
-About us: http://piwik.org/team/
 
 ## More information
 
diff --git a/config/global.ini.php b/config/global.ini.php
index c62c624fa24a75c1b337252101f23d04bdeaec28..b5d8e51d3290f7e333d2081ea2a1df9f87ef1efd 100644
--- a/config/global.ini.php
+++ b/config/global.ini.php
@@ -565,9 +565,8 @@ pivot_by_filter_enable_fetch_by_segment = 0
 ; on a per-request basis;
 pivot_by_filter_default_column_limit = 10
 
-; If set to 0 it will disable Piwik Pro advertisements in some places. For example in the installation screen, the
-; Piwik Pro Ad widget will be removed etc.
-piwik_pro_ads_enabled = 1
+; If set to 0 it will disable advertisements for providers of Professional Support for Piwik.
+piwik_professional_support_ads_enabled = 1
 
 [Tracker]
 
@@ -804,7 +803,7 @@ Plugins[] = Resolution
 Plugins[] = DevicePlugins
 Plugins[] = Heartbeat
 Plugins[] = Intl
-Plugins[] = PiwikPro
+Plugins[] = ProfessionalServices
 Plugins[] = UserId
 
 [PluginsInstalled]
diff --git a/core/Config.php b/core/Config.php
index adc3ba948de149bbab264e2b6e04e56fe3984a4b..01fa144a5cd89d7cddaecc0dcb33c82a2ed178de 100644
--- a/core/Config.php
+++ b/core/Config.php
@@ -12,6 +12,7 @@ namespace Piwik;
 use Exception;
 use Piwik\Application\Kernel\GlobalSettingsProvider;
 use Piwik\Container\StaticContainer;
+use Piwik\ProfessionalServices\Advertising;
 
 /**
  * Singleton that provides read & write access to Piwik's INI configuration.
@@ -158,7 +159,7 @@ class Config
             'autocomplete_min_sites' => $general['autocomplete_min_sites'],
             'datatable_export_range_as_day' => $general['datatable_export_range_as_day'],
             'datatable_row_limits' => $this->getDatatableRowLimits(),
-            'are_ads_enabled' => $general['piwik_pro_ads_enabled']
+            'are_ads_enabled' => Advertising::isAdsEnabledInConfig($general)
         );
     }
 
diff --git a/core/Console.php b/core/Console.php
index 6b0c59297f3d69e8b13e6bc2e0b5c3b5b1c840e7..e326211ef80757b3bf0093b74a219b4a160be283 100644
--- a/core/Console.php
+++ b/core/Console.php
@@ -209,12 +209,6 @@ class Console extends Application
         $commands = array(
             'Piwik\CliMulti\RequestCommand'
         );
-
-        if (class_exists('Piwik\Plugins\EnterpriseAdmin\EnterpriseAdmin')) {
-            $extra = new \Piwik\Plugins\EnterpriseAdmin\EnterpriseAdmin();
-            $extra->addConsoleCommands($commands);
-        }
-
         return $commands;
     }
 }
diff --git a/core/Twig.php b/core/Twig.php
index 8f5811714b9d285f3a13fae5bc4204157ae96097..5ac84993f126d391e88803b7f4ee4adc64b609f8 100755
--- a/core/Twig.php
+++ b/core/Twig.php
@@ -173,9 +173,6 @@ class Twig
         $this->addFilter_percent();
         $this->addFilter_percentage();
         $this->addFilter_percentEvolution();
-        $this->addFilter_piwikProAdLink();
-        $this->addFilter_piwikProOnPremisesAdLink();
-        $this->addFilter_piwikProCloudAdLink();
         $this->addFilter_prettyDate();
         $this->addFilter_safeDecodeRaw();
         $this->addFilter_number();
@@ -418,47 +415,9 @@ class Twig
         $this->twig->addFilter($percentage);
     }
 
-    protected function addFilter_piwikProAdLink()
+    private function getProfessionalServicesAdvertising()
     {
-        $ads = $this->getPiwikProAdvertising();
-        $piwikProAd = new Twig_SimpleFilter('piwikProCampaignParameters', function ($url, $campaignName, $campaignMedium, $campaignContent = '') use ($ads) {
-            $url = $ads->addPromoCampaignParametersToUrl($url, $campaignName, $campaignMedium, $campaignContent);
-            return $url;
-        });
-        $this->twig->addFilter($piwikProAd);
-    }
-
-    protected function addFilter_piwikProOnPremisesAdLink()
-    {
-        $twigEnv = $this->getTwigEnvironment();
-        $ads = $this->getPiwikProAdvertising();
-        $piwikProAd = new Twig_SimpleFilter('piwikProOnPremisesPromoUrl', function ($medium, $content = '') use ($twigEnv, $ads) {
-
-            $url = $ads->getPromoUrlForOnPremises($medium, $content);
-
-            return twig_escape_filter($twigEnv, $url, 'html_attr');
-
-        }, array('is_safe' => array('html_attr')));
-        $this->twig->addFilter($piwikProAd);
-    }
-
-    protected function addFilter_piwikProCloudAdLink()
-    {
-        $twigEnv = $this->getTwigEnvironment();
-        $ads = $this->getPiwikProAdvertising();
-        $piwikProAd = new Twig_SimpleFilter('piwikProCloudPromoUrl', function ($medium, $content = '') use ($twigEnv, $ads) {
-
-            $url = $ads->getPromoUrlForCloud($medium, $content);
-
-            return twig_escape_filter($twigEnv, $url, 'html_attr');
-
-        }, array('is_safe' => array('html_attr')));
-        $this->twig->addFilter($piwikProAd);
-    }
-
-    private function getPiwikProAdvertising()
-    {
-        return StaticContainer::get('Piwik\PiwikPro\Advertising');
+        return StaticContainer::get('Piwik\ProfessionalServices\Advertising');
     }
 
     protected function addFilter_number()
diff --git a/core/Updates/2.16.0-rc2.php b/core/Updates/2.16.0-rc2.php
deleted file mode 100644
index 2bddb6b5cb84055f38d6b260faef312323058a3f..0000000000000000000000000000000000000000
--- a/core/Updates/2.16.0-rc2.php
+++ /dev/null
@@ -1,28 +0,0 @@
-<?php
-/**
- * Piwik - free/libre analytics platform
- *
- * @link http://piwik.org
- * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- */
-
-namespace Piwik\Updates;
-
-use Piwik\Updater;
-use Piwik\Updates;
-
-class Updates_2_16_0_rc2 extends Updates
-{
-    public function doUpdate(Updater $updater)
-    {
-        $pluginManager = \Piwik\Plugin\Manager::getInstance();
-        $pluginName = 'PiwikPro';
-
-        try {
-            if (!$pluginManager->isPluginActivated($pluginName)) {
-                $pluginManager->activatePlugin($pluginName);
-            }
-        } catch (\Exception $e) {
-        }
-    }
-}
\ No newline at end of file
diff --git a/core/Updates/2.16.2-b5.php b/core/Updates/2.16.2-b5.php
new file mode 100644
index 0000000000000000000000000000000000000000..26a7f48920e35b96c06d98665999b4adb1a3c643
--- /dev/null
+++ b/core/Updates/2.16.2-b5.php
@@ -0,0 +1,34 @@
+<?php
+/**
+ * Piwik - free/libre analytics platform
+ *
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
+ *
+ */
+
+namespace Piwik\Updates;
+
+use Piwik\Updater;
+use Piwik\Updates as PiwikUpdates;
+
+/**
+ * Update for version 2.16.2-b5
+ */
+class Updates_2_16_2_b5 extends PiwikUpdates
+{
+
+    public function doUpdate(Updater $updater)
+    {
+        try {
+            \Piwik\Plugin\Manager::getInstance()->activatePlugin('ProfessionalServices');
+        } catch (\Exception $e) {
+        }
+
+        try {
+            \Piwik\Plugin\Manager::getInstance()->deactivatePlugin('ProfessionalServices');
+            self::deletePluginFromConfigFile('ProfessionalServices');
+        } catch (\Exception $e) {
+        }
+    }
+}
diff --git a/core/testMinimumPhpVersion.php b/core/testMinimumPhpVersion.php
index 034c9d7e6bbd2bbf86fa8c55ff8c93514613ac93..37ab78ca7f46fa6d79cb85cc13b2c7e20fc99039 100644
--- a/core/testMinimumPhpVersion.php
+++ b/core/testMinimumPhpVersion.php
@@ -144,7 +144,7 @@ if (!function_exists('Piwik_GetErrorMessagePage')) {
                             <li><a rel="noreferrer" target="_blank" href="http://piwik.org/faq/">Piwik Frequently Asked Questions</a></li>
                             <li><a rel="noreferrer" target="_blank" href="http://piwik.org/docs/">Piwik Documentation</a></li>
                             <li><a rel="noreferrer" target="_blank" href="http://forum.piwik.org/">Piwik Forums</a></li>
-                            <li><a rel="noreferrer" target="_blank" href="https://piwik.pro/contact/?pk_campaign=App_AnErrorOccured&pk_source=Piwik_App&pk_medium=ProfessionalServicesLink#contact-form">Professional help (Piwik PRO)</a></li>
+                            <li><a rel="noreferrer" target="_blank" href="https://piwik.org/support/?pk_campaign=App_AnErrorOccured&pk_source=Piwik_App&pk_medium=ProfessionalServicesLink">Professional help for Piwik</a></li>
                             </ul>';
         }
         if ($optionalLinkBack) {
diff --git a/lang/en.json b/lang/en.json
index 965c5ab1bddeee656ae890438bff06d68cc70449..a9856cc42541ffa83691da5fda6127970326bc7a 100644
--- a/lang/en.json
+++ b/lang/en.json
@@ -286,7 +286,7 @@
         "Password": "Password",
         "Period": "Period",
         "Piechart": "Piechart",
-        "PiwikIsACollaborativeProjectYouCanContributeAndDonate": "%1$sPiwik%2$s is a collaborative project brought to you by the %7$sPiwik team%8$s members as well as many other contributors around the globe. If you're a fan of Piwik, you can help: find out %3$sHow to participate in Piwik%4$s, or %5$sdonate now%6$s to help fund Piwik 3.0!",
+        "PiwikIsACollaborativeProjectYouCanContributeAndDonate": "%1$sPiwik%2$s is a collaborative project brought to you by the %7$sPiwik team%8$s members as well as many other contributors around the globe. <br/> If you're a fan of Piwik, you can help: find out %3$sHow to participate in Piwik%4$s, or %5$sdonate now%6$s to help fund Piwik 3.0!",
         "PiwikXIsAvailablePleaseNotifyPiwikAdmin": "%1$s is available. Please notify the %2$sPiwik administrator%3$s.",
         "PiwikXIsAvailablePleaseUpdateNow": "Piwik %1$s is available. %2$sPlease update now!%3$s (see %4$schanges%5$s).",
         "PleaseSpecifyValue": "Please specify a value for '%s'.",
diff --git a/plugins/CoreConsole/Commands/ManagePlugin.php b/plugins/CoreConsole/Commands/ManagePlugin.php
index 3f07918f7c64ba1c733d04defff086c2ce939cf7..0f2294c7e0fd29e2670e39bc1e4422698d907095 100644
--- a/plugins/CoreConsole/Commands/ManagePlugin.php
+++ b/plugins/CoreConsole/Commands/ManagePlugin.php
@@ -41,7 +41,7 @@ class ManagePlugin extends ConsoleCommand
     }
 
     /**
-     * Execute command like: ./console core:plugin activate CustomAlerts --piwik-domain=testcustomer.piwik.pro
+     * Execute command like: ./console core:plugin activate CustomAlerts --piwik-domain=testcustomer.example.com
      */
     protected function execute(InputInterface $input, OutputInterface $output)
     {
diff --git a/plugins/CoreHome/templates/getDefaultIndexView.twig b/plugins/CoreHome/templates/getDefaultIndexView.twig
index 62e8d8ffe7771e23c31c7075ab56df5b8cd2d989..62553e1ffed0e78699d9e768a9d6c16e01d54ea7 100644
--- a/plugins/CoreHome/templates/getDefaultIndexView.twig
+++ b/plugins/CoreHome/templates/getDefaultIndexView.twig
@@ -10,7 +10,7 @@
 {% endblock %}
 
 {% block content %}
-    {{ ajax.requestErrorDiv(emailSuperUser|default(''), arePiwikProAdsEnabled) }}
+    {{ ajax.requestErrorDiv(emailSuperUser|default(''), areAdsForProfessionalServicesEnabled, currentModule) }}
     {{ ajax.loadingDiv() }}
 
     <div id="content" class="home">
diff --git a/plugins/CoreUpdater/lang/en.json b/plugins/CoreUpdater/lang/en.json
index 518631531077a20375b01fae1a855f0eca6046cf..8086f16b36ade4b7147f69c3655adeac00868dbd 100644
--- a/plugins/CoreUpdater/lang/en.json
+++ b/plugins/CoreUpdater/lang/en.json
@@ -57,7 +57,7 @@
         "ThankYouUpdatePiwik": "Thank you for using Piwik and keeping it up to date!",
         "PostUpdateMessage": "Piwik will always be free to download and use, but it needs your continued support to grow and improve.",
         "PostUpdateSupport": "If you need help using Piwik, you can get support from its creators:",
-        "EnterpriseSolutions": "Enterprise solutions",
+        "ProfessionalServices": "Professional Services",
         "CloudHosting": "Cloud hosting",
         "Updating": "Updating",
         "UpdateUsingHttpsFailed": "Downloading the latest Piwik version over secure HTTPS connection did not succeed, because of the following error:",
diff --git a/plugins/CoreUpdater/templates/updateSuccess.twig b/plugins/CoreUpdater/templates/updateSuccess.twig
index 3ce45af298151821eb965e5c823ef6b9b0bddb8b..661c8ded4dd9dcf1f2ab91167d72d23242c2cb72 100644
--- a/plugins/CoreUpdater/templates/updateSuccess.twig
+++ b/plugins/CoreUpdater/templates/updateSuccess.twig
@@ -22,12 +22,13 @@
             {{ 'CoreUpdater_PostUpdateSupport'|translate }}
         </h2>
 
-        <div class="row">
+        <div class="row" style="margin-top:7%">
             <div class="col-sm-5 col-sm-offset-1">
-                <a href="https://piwik.pro/enterprise?pk_medium=App_Enterprise_button&pk_source=Piwik_App&pk_campaign=App_Updated" class="btn btn-lg btn-block">{{ 'CoreUpdater_EnterpriseSolutions'|translate }}</a>
+                <a href="https://piwik.org/support/?pk_medium=Update_Success_button&pk_source=Piwik_App&pk_campaign=App_Updated" class="btn btn-lg btn-block">{{ 'CoreUpdater_ProfessionalServices'|translate }}</a>
             </div>
+
             <div class="col-sm-5">
-                <a href="https://piwik.pro/cloud?pk_medium=App_Cloud_button&pk_source=Piwik_App&pk_campaign=App_Updated" class="btn btn-lg btn-block">{{ 'CoreUpdater_CloudHosting'|translate }}</a>
+                <a href="https://piwik.org/hosting/?pk_medium=App_Cloud_button&pk_source=Piwik_App&pk_campaign=App_Updated" class="btn btn-lg btn-block">{{ 'CoreUpdater_CloudHosting'|translate }}</a>
             </div>
         </div>
 
diff --git a/plugins/Dashboard/Dashboard.php b/plugins/Dashboard/Dashboard.php
index 729f845c7033cf6d24a08ee7104ce0e0be3f9611..c25122bcea054876d7a5df890f4bf4644e265400 100644
--- a/plugins/Dashboard/Dashboard.php
+++ b/plugins/Dashboard/Dashboard.php
@@ -64,10 +64,10 @@ class Dashboard extends \Piwik\Plugin
         if (empty($defaultLayout)) {
             $topWidget = '';
 
-            $advertising = StaticContainer::get('Piwik\PiwikPro\Advertising');
-            if ($advertising->arePiwikProAdsEnabled() && Plugin\Manager::getInstance()->isPluginActivated('PiwikPro')) {
-                $topWidget .= '{"uniqueId":"widgetPiwikPropromoPiwikPro",'
-                    . '"parameters":{"module":"PiwikPro","action":"promoPiwikPro"}},';
+            $advertising = StaticContainer::get('Piwik\ProfessionalServices\Advertising');
+            if ($advertising->areAdsForProfessionalServicesEnabled() && Plugin\Manager::getInstance()->isPluginActivated('ProfessionalServices')) {
+                $topWidget .= '{"uniqueId":"widgetProfessionalServicespromoServices",'
+                    . '"parameters":{"module":"ProfessionalServices","action":"promoServices"}},';
             }
 
             if (Piwik::hasUserSuperUserAccess()) {
diff --git a/plugins/DevicesDetection/plugin.json b/plugins/DevicesDetection/plugin.json
deleted file mode 100644
index 5a522126b8aa0863fdf97e46845b6dfbc8372ad6..0000000000000000000000000000000000000000
--- a/plugins/DevicesDetection/plugin.json
+++ /dev/null
@@ -1,8 +0,0 @@
-{
-  "authors": [
-    {
-      "name": "Piwik PRO",
-      "homepage": "http://piwik.pro"
-    }
-  ]
-}
diff --git a/plugins/Feedback/lang/en.json b/plugins/Feedback/lang/en.json
index 4d55bcfe7a83c3829a919e76f02743ef00f9b882..d16f70a86bbb7e3410a028c66c87a98ea08e9cf3 100644
--- a/plugins/Feedback/lang/en.json
+++ b/plugins/Feedback/lang/en.json
@@ -19,15 +19,15 @@
         "ViewUserGuides": "Learn how to configure Piwik and how to effectively analyze your data with our %1$suser guides%2$s",
         "CommunityHelp": "Community Help",
         "ProfessionalHelp": "Professional Help",
-        "PiwikProIntro": "Piwik PRO provides expert support and consulting to clients who host Piwik on their own infrastructure.",
-        "PiwikProOfferIntro": "Our offer includes",
-        "PiwikProReviewPiwikSetup": "A review of your Piwik setup",
-        "PiwikProOptimizationMaintenance": "Piwik optimization & maintenance services",
-        "PiwikProPhoneEmailSupport": "Phone and Email support",
-        "PiwikProTraining": "User, Technical and Developer training",
-        "PiwikProPremiumFeatures": "Premium features",
-        "PiwikProCustomDevelopment": "Custom Development services",
-        "PiwikProAnalystConsulting": "Analyst consulting services",
+        "ProfessionalServicesIntro": "Our worldwide network of professional consultants for Piwik support clients who host Piwik on their own infrastructure.",
+        "ProfessionalServicesOfferIntro": "What services can you benefit from?",
+        "ProfessionalServicesReviewPiwikSetup": "A review of your Piwik setup",
+        "ProfessionalServicesOptimizationMaintenance": "Piwik optimization & maintenance services",
+        "ProfessionalServicesPhoneEmailSupport": "Phone and Email support",
+        "ProfessionalServicesTraining": "User, Technical and Developer training",
+        "ProfessionalServicesPremiumFeatures": "Premium features",
+        "ProfessionalServicesCustomDevelopment": "Custom Development services",
+        "ProfessionalServicesAnalystConsulting": "Analyst consulting services",
         "ContactUs": "Contact us",
         "VisitTheForums": "Visit the %1$s Forums%2$s and get help from the community of Piwik users"
     }
diff --git a/plugins/Feedback/templates/index.twig b/plugins/Feedback/templates/index.twig
index 31e1ec83fc12d4b3f6b3b95b1305fca2bbbf16ea..74818d92138f896e46e89b1caf2dac7dc20bc3d0 100644
--- a/plugins/Feedback/templates/index.twig
+++ b/plugins/Feedback/templates/index.twig
@@ -41,19 +41,19 @@
         <h2>{{ 'Feedback_ProfessionalHelp'|translate }}</h2>
 
         <div class="header_full">
-            <p>{{ 'Feedback_PiwikProIntro'|translate }}</p>
+            <p>{{ 'Feedback_ProfessionalServicesIntro'|translate }}</p>
 
-            <p>{{ 'Feedback_PiwikProOfferIntro'|translate }}:</p>
-            <p> &bull; {{ 'Feedback_PiwikProReviewPiwikSetup'|translate }}</p>
-            <p> &bull; {{ 'Feedback_PiwikProOptimizationMaintenance'|translate }}</p>
-            <p> &bull; {{ 'Feedback_PiwikProPhoneEmailSupport'|translate }}</p>
-            <p> &bull; {{ 'Feedback_PiwikProTraining'|translate }}</p>
-            <p> &bull; {{ 'Feedback_PiwikProPremiumFeatures'|translate }}</p>
-            <p> &bull; {{ 'Feedback_PiwikProCustomDevelopment'|translate }}</p>
-            <p> &bull; {{ 'Feedback_PiwikProAnalystConsulting'|translate }}</p>
+            <p>{{ 'Feedback_ProfessionalServicesOfferIntro'|translate }}</p>
+            <p> &bull; {{ 'Feedback_ProfessionalServicesReviewPiwikSetup'|translate }}</p>
+            <p> &bull; {{ 'Feedback_ProfessionalServicesOptimizationMaintenance'|translate }}</p>
+            <p> &bull; {{ 'Feedback_ProfessionalServicesPhoneEmailSupport'|translate }}</p>
+            <p> &bull; {{ 'Feedback_ProfessionalServicesTraining'|translate }}</p>
+            <p> &bull; {{ 'Feedback_ProfessionalServicesPremiumFeatures'|translate }}</p>
+            <p> &bull; {{ 'Feedback_ProfessionalServicesCustomDevelopment'|translate }}</p>
+            <p> &bull; {{ 'Feedback_ProfessionalServicesAnalystConsulting'|translate }}</p>
         </div>
 
-        <form target="_blank" action="https://piwik.pro/contact#contact-form">
+        <form target="_blank" action="https://piwik.org/support/">
             <input type="hidden" name="pk_campaign" value="App_Help">
             <input type="hidden" name="pk_source" value="Piwik_App">
             <input type="hidden" name="pk_medium" value="App_ContactUs_button">
diff --git a/plugins/Installation/Controller.php b/plugins/Installation/Controller.php
index e91ab0355c24fb5b67f3440717ff670fd229f01b..f75477f6596e54ed2aff4c990988cb645a0cd68c 100644
--- a/plugins/Installation/Controller.php
+++ b/plugins/Installation/Controller.php
@@ -279,8 +279,8 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
 
                 $email = $form->getSubmitValue('email');
                 $newsletterPiwikORG = $form->getSubmitValue('subscribe_newsletter_piwikorg');
-                $newsletterPiwikPRO = $form->getSubmitValue('subscribe_newsletter_piwikpro');
-                $this->registerNewsletter($email, $newsletterPiwikORG, $newsletterPiwikPRO);
+                $newsletterProfessionalServices = $form->getSubmitValue('subscribe_newsletter_professionalservices');
+                $this->registerNewsletter($email, $newsletterPiwikORG, $newsletterProfessionalServices);
                 $this->redirectToNextStep(__FUNCTION__);
 
             } catch (Exception $e) {
@@ -425,6 +425,7 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
         $view->addForm($form);
 
         $view->showNextStep = false;
+        $view->linkToProfessionalServices = StaticContainer::get('Piwik\ProfessionalServices\Advertising')->getPromoUrlForProfessionalServices($medium = 'App_InstallationFinished');
         $output = $view->render();
 
         return $output;
@@ -670,16 +671,16 @@ class Controller extends \Piwik\Plugin\ControllerAdmin
     /**
      * @param $email
      * @param $newsletterPiwikORG
-     * @param $newsletterPiwikPRO
+     * @param $newsletterProfessionalServices
      */
-    protected function registerNewsletter($email, $newsletterPiwikORG, $newsletterPiwikPRO)
+    protected function registerNewsletter($email, $newsletterPiwikORG, $newsletterProfessionalServices)
     {
         $url = Config::getInstance()->General['api_service_url'];
         $url .= '/1.0/subscribeNewsletter/';
         $params = array(
             'email'     => $email,
             'piwikorg'  => $newsletterPiwikORG,
-            'piwikpro'  => $newsletterPiwikPRO,
+            'piwikpro'  => $newsletterProfessionalServices,
             'url'       => Url::getCurrentUrlWithoutQueryString(),
             'language'  => StaticContainer::get('Piwik\Translation\Translator')->getCurrentLanguage(),
         );
diff --git a/plugins/Installation/FormSuperUser.php b/plugins/Installation/FormSuperUser.php
index c4b1d0944dfaaf348c68288dd968b1922da9d200..87abc026fdf1261c97b35935006bcb5331c856cb 100644
--- a/plugins/Installation/FormSuperUser.php
+++ b/plugins/Installation/FormSuperUser.php
@@ -59,22 +59,15 @@ class FormSuperUser extends QuickForm2
                 'content' => '&nbsp;&nbsp;' . Piwik::translate('Installation_PiwikOrgNewsletter'),
             ));
 
-        $piwikProNewsletter = Piwik::translate('Installation_PiwikProNewsletter',
-            array("<a href='http://piwik.pro?pk_medium=App_Newsletter_link&pk_source=Piwik_App&pk_campaign=App_Installation' style='color:#444;' rel='noreferrer' target='_blank'>", "</a>")
+        $professionalServicesNewsletter = Piwik::translate('Installation_ProfessionalServicesNewsletter',
+            array("<a href='http://piwik.org/consulting/?pk_medium=App_Newsletter_link&pk_source=Piwik_App&pk_campaign=App_Installation' style='color:#444;' rel='noreferrer' target='_blank'>", "</a>")
         );
 
         $currentLanguage = StaticContainer::get('Piwik\Translation\Translator')->getCurrentLanguage();
 
-        if ($currentLanguage == 'de') {
-            $piwikProNewsletter = Piwik::translate('Installation_PiwikProNewsletter',
-                array("<a href='http://piwikpro.de?pk_medium=App_Newsletter_link&pk_source=Piwik_App&pk_campaign=App_Installation' style='color:#444;' rel='noreferrer' target='_blank'>", "</a>")
-            );
-            $piwikProNewsletter = preg_replace('(Piwik PRO(?! GmbH))', 'Piwik PRO GmbH', $piwikProNewsletter);
-        }
-
-        $this->addElement('checkbox', 'subscribe_newsletter_piwikpro', null,
+        $this->addElement('checkbox', 'subscribe_newsletter_professionalservices', null,
             array(
-                'content' => '&nbsp;&nbsp;' . $piwikProNewsletter,
+                'content' => '&nbsp;&nbsp;' . $professionalServicesNewsletter,
             ));
 
         $this->addElement('submit', 'submit', array('value' => Piwik::translate('General_Next') . ' »', 'class' => 'btn btn-lg'));
@@ -82,7 +75,7 @@ class FormSuperUser extends QuickForm2
         // default values
         $this->addDataSource(new HTML_QuickForm2_DataSource_Array(array(
             'subscribe_newsletter_piwikorg' => 1,
-            'subscribe_newsletter_piwikpro' => $currentLanguage == 'de' ? 0 : 1,
+            'subscribe_newsletter_professionalservices' => $currentLanguage == 'de' ? 0 : 1,
         )));
     }
 }
diff --git a/plugins/Installation/lang/en.json b/plugins/Installation/lang/en.json
index c67066b2014193b7698854f80f629d43c620deab..725c3bfde2f3663b2d4c6e0243b34e9a203a845d 100644
--- a/plugins/Installation/lang/en.json
+++ b/plugins/Installation/lang/en.json
@@ -44,8 +44,9 @@
         "PasswordDoNotMatch": "password do not match",
         "PasswordRepeat": "Password (repeat)",
         "PercentDone": "%s %% Done",
-        "PiwikProAdTitle": "Advanced Analytics & Services",
-        "PiwikProAdText": "Add premium functionality and unlock the full power with %1$sPiwik PRO On-Premises%2$s, or get your own hassle-free Piwik hosted in the %3$sPiwik PRO Cloud%4$s.",
+        "ProfessionalServicesAdTitle": "Advanced Analytics & Services",
+        "ProfessionalServicesfessionalServicesAdText": "Our network of experts can help your organization unlock the full power of Piwik analytics. ",
+        "ProfessionalServicesfessionalDiscoverHow": "Learn about %1$sadditional products and services%2$s for Piwik and how to increase your conversions and revenue.",
         "PleaseFixTheFollowingErrors": "Please fix the following errors",
         "DefaultSettings": "Default Piwik settings",
         "DefaultSettingsHelp": "Piwik comes with default settings. You can customize them now or do so later in the admin screen.",
@@ -53,7 +54,7 @@
         "RestartWebServer": "After making this change, restart your web server.",
         "ReusingTables": "Reusing the Tables",
         "PiwikOrgNewsletter": "email me with major Piwik community updates",
-        "PiwikProNewsletter": "send me information on %1$sPiwik PRO%2$s services and offers",
+        "ProfessionalServicesNewsletter": "send me information on %1$sProfessional services and products%2$s for Piwik",
         "SeeBelowForMoreInfo": "See below for more information.",
         "SetupWebsite": "Setup a Website",
         "SetupWebsiteError": "There was an error when adding the website",
diff --git a/plugins/Installation/templates/finished.twig b/plugins/Installation/templates/finished.twig
index b64bb79812d48cdd3a6ccf09afd82360c3ade44c..133bdc6ab4fa239e83590b77bca64d0fb9562875 100644
--- a/plugins/Installation/templates/finished.twig
+++ b/plugins/Installation/templates/finished.twig
@@ -17,13 +17,13 @@
     <p>{{ 'Installation_WeHopeYouWillEnjoyPiwik'|translate }}</p>
     <p><i>{{ 'Installation_HappyAnalysing'|translate }}</i></p>
 
-    {% if arePiwikProAdsEnabled %}
-        <h3>{{ 'Installation_PiwikProAdTitle'|translate }}</h3>
+    {% if areAdsForProfessionalServicesEnabled %}
+        <h3>{{ 'Installation_ProfessionalServicesAdTitle'|translate }}</h3>
         <p>
-            {% set linkOnPremises = 'Installation_End'|piwikProOnPremisesPromoUrl %}
-            {% set linkOnCloud = 'Installation_End'|piwikProCloudPromoUrl %}
-
-            {{ 'Installation_PiwikProAdText'|translate('<a rel="noreferrer" target="_blank" href="' ~ linkOnPremises ~ '">','</a>', '<a  rel="noreferrer"  target="_blank" href="' ~ linkOnCloud ~ '">','</a>')|raw }}
+            {{ 'Installation_ProfessionalServicesfessionalServicesAdText'|translate }}
+        </p>
+        <p>
+            {{ 'Installation_ProfessionalServicesfessionalDiscoverHow'|translate('<a rel="noreferrer" target="_blank" href="' ~ linkToProfessionalServices ~ '">','</a>')|raw }}
         </p>
     {% endif %}
 
diff --git a/plugins/Morpheus/templates/admin.twig b/plugins/Morpheus/templates/admin.twig
index 143d5a9f07ab9a18e4c8c912642a992b9ed4e8b7..2ddf3e692923ef539e39f21f31129a02f75d06c6 100644
--- a/plugins/Morpheus/templates/admin.twig
+++ b/plugins/Morpheus/templates/admin.twig
@@ -19,7 +19,7 @@
     {% include "@CoreHome/_topScreen.twig" %}
 
     {% import 'ajaxMacros.twig' as ajax %}
-    {{ ajax.requestErrorDiv(emailSuperUser|default(''), arePiwikProAdsEnabled) }}
+    {{ ajax.requestErrorDiv(emailSuperUser|default(''), areAdsForProfessionalServicesEnabled, currentModule) }}
     {{ postEvent("Template.beforeContent", "admin", currentModule) }}
 
     <div class="page">
diff --git a/plugins/Morpheus/templates/ajaxMacros.twig b/plugins/Morpheus/templates/ajaxMacros.twig
index 267ff8e83dddad0bb24f71bb9578fb89c7e2422a..2a4584c425e0b2228c09a1a094f1481b53f545f0 100644
--- a/plugins/Morpheus/templates/ajaxMacros.twig
+++ b/plugins/Morpheus/templates/ajaxMacros.twig
@@ -13,7 +13,7 @@
 </div>
 {% endmacro %}
 
-{% macro requestErrorDiv(emailSuperUser, arePiwikProAdsEnabled = false) %}
+{% macro requestErrorDiv(emailSuperUser, areAdsForProfessionalServicesEnabled = false, currentModule = '') %}
     <div id="loadingError">
         <div class="alert alert-danger">
 
@@ -29,9 +29,10 @@
             <a rel="noreferrer" target="_blank" href="https://piwik.org/faq/troubleshooting/faq_19489/">{{ 'General_Faq'|translate }}</a> –
             <a rel="noreferrer" target="_blank" href="http://forum.piwik.org/">{{ 'Feedback_CommunityHelp'|translate }}</a>
 
-            {%- if arePiwikProAdsEnabled %}
+            {%- if areAdsForProfessionalServicesEnabled %}
                 –
-                <a rel="noreferrer" target="_blank" href="{{ 'https://piwik.pro/'|piwikProCampaignParameters('Help', 'AjaxError')|e('html_attr') }}">{{ 'Feedback_ProfessionalHelp'|translate }}</a>
+                {% set supportUrl = 'https://piwik.org/support/?pk_campaign=Help&pk_medium=AjaxError&pk_content=' ~ currentModule ~ '&pk_source=Piwik_App' %}
+                <a rel="noreferrer" target="_blank" href="{{ supportUrl|e('html_attr') }}">{{ 'Feedback_ProfessionalHelp'|translate }}</a>
             {%- endif %}.
         </div>
     </div>
diff --git a/plugins/Morpheus/templates/user.twig b/plugins/Morpheus/templates/user.twig
index b343961eaee37c65231c244497b1795db397389d..f13dc1ebd48795ae66f922aa793eaf6350d6c05f 100644
--- a/plugins/Morpheus/templates/user.twig
+++ b/plugins/Morpheus/templates/user.twig
@@ -21,7 +21,7 @@
     {% include "@CoreHome/_topScreen.twig" %}
 
     {% import 'ajaxMacros.twig' as ajax %}
-    {{ ajax.requestErrorDiv(emailSuperUser|default(''), arePiwikProAdsEnabled) }}
+    {{ ajax.requestErrorDiv(emailSuperUser|default(''), areAdsForProfessionalServicesEnabled, currentModule) }}
     {{ postEvent("Template.beforeContent", "user", currentModule) }}
 
     <div class="page">
diff --git a/plugins/MultiSites/angularjs/dashboard/dashboard.controller.js b/plugins/MultiSites/angularjs/dashboard/dashboard.controller.js
index 35cf26a5de819dd294759616857ad56f1c242eb8..41fcb81d9f607e21a6b0838a1f712bc05ff21562 100644
--- a/plugins/MultiSites/angularjs/dashboard/dashboard.controller.js
+++ b/plugins/MultiSites/angularjs/dashboard/dashboard.controller.js
@@ -19,7 +19,7 @@
         $scope.idSite = piwik.broadcast.getValueFromUrl('idSite');
         $scope.url  = piwik.piwik_url;
         $scope.period = piwik.period;
-        $scope.arePiwikProAdsEnabled = piwik.config && piwik.config.are_ads_enabled;
+        $scope.areAdsForProfessionalServicesEnabled = piwik.config && piwik.config.are_ads_enabled;
 
         this.refresh = function (interval) {
             multisitesDashboardModel.refreshInterval = interval;
diff --git a/plugins/MultiSites/angularjs/dashboard/dashboard.directive.html b/plugins/MultiSites/angularjs/dashboard/dashboard.directive.html
index 06a7fb66137532e74a5f50d87918044cefd9dd6d..9c7f0f5f21de4fabf814d2afe0649a80cf5ff2cc 100644
--- a/plugins/MultiSites/angularjs/dashboard/dashboard.directive.html
+++ b/plugins/MultiSites/angularjs/dashboard/dashboard.directive.html
@@ -66,8 +66,8 @@
                         <a rel="noreferrer" target="_blank" href="https://piwik.org/faq/troubleshooting/faq_19489/">{{ 'General_Faq'|translate }}</a>
                         –
                         <a rel="noreferrer" target="_blank" href="http://forum.piwik.org/">{{ 'Feedback_CommunityHelp'|translate }}</a>
-                        <span ng-show="arePiwikProAdsEnabled"> – </span>
-                        <a ng-show="arePiwikProAdsEnabled" rel="noreferrer" target="_blank" href="https://piwik.pro/?pk_campaign=Help&pk_medium=AjaxError&pk_content=MultiSites&pk_source=Piwik_App">{{ 'Feedback_ProfessionalHelp'|translate }}</a>.
+                        <span ng-show="areAdsForProfessionalServicesEnabled"> – </span>
+                        <a ng-show="areAdsForProfessionalServicesEnabled" rel="noreferrer" target="_blank" href="https://piwik.org/support/?pk_campaign=Help&pk_medium=AjaxError&pk_content=MultiSites&pk_source=Piwik_App">{{ 'Feedback_ProfessionalHelp'|translate }}</a>.
                     </div>
                 </td>
             </tr>
diff --git a/plugins/MultiSites/plugin.json b/plugins/MultiSites/plugin.json
deleted file mode 100644
index 1bf22b2dbd1f658808ace3e7e8463b4d961a539a..0000000000000000000000000000000000000000
--- a/plugins/MultiSites/plugin.json
+++ /dev/null
@@ -1,8 +0,0 @@
-{
-  "authors": [
-    {
-      "name": "Piwik PRO",
-      "homepage": "http://piwik.pro"
-    }
-  ]
-}
\ No newline at end of file
diff --git a/plugins/PiwikPro/PiwikPro.php b/plugins/PiwikPro/PiwikPro.php
deleted file mode 100644
index 590b2a94b59784abcebc2b05d1d0ece79d844c4d..0000000000000000000000000000000000000000
--- a/plugins/PiwikPro/PiwikPro.php
+++ /dev/null
@@ -1,27 +0,0 @@
-<?php
-/**
- * Piwik - free/libre analytics platform
- *
- * @link http://piwik.org
- * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- */
-
-namespace Piwik\Plugins\PiwikPro;
-
-class PiwikPro extends \Piwik\Plugin
-{
-    /**
-     * @see Piwik\Plugin::registerEvents
-     */
-    public function registerEvents()
-    {
-        return array(
-            'AssetManager.getStylesheetFiles' => 'getStylesheetFiles',
-        );
-    }
-
-    public function getStylesheetFiles(&$stylesheets)
-    {
-        $stylesheets[] = 'plugins/PiwikPro/stylesheets/widget.less';
-    }
-}
diff --git a/plugins/PiwikPro/Widgets.php b/plugins/PiwikPro/Widgets.php
deleted file mode 100644
index f8e007aa074f3a84fe0bc690adf1549c547b23ba..0000000000000000000000000000000000000000
--- a/plugins/PiwikPro/Widgets.php
+++ /dev/null
@@ -1,82 +0,0 @@
-<?php
-/**
- * Piwik - free/libre analytics platform
- *
- * @link http://piwik.org
- * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
- *
- */
-namespace Piwik\Plugins\PiwikPro;
-
-use Piwik\Piwik;
-use Piwik\PiwikPro\Advertising;
-use Piwik\Plugins\ExampleRssWidget\RssRenderer;
-use Piwik\View;
-
-class Widgets extends \Piwik\Plugin\Widgets
-{
-    protected $category = 'About Piwik';
-
-    /**
-     * @var Advertising
-     */
-    private $advertising;
-
-    /**
-     * @var Promo
-     */
-    private $promo;
-
-    public function __construct(Advertising $advertising, Promo $promo)
-    {
-        $this->advertising = $advertising;
-        $this->promo = $promo;
-    }
-
-    protected function init()
-    {
-        if ($this->advertising->arePiwikProAdsEnabled()) {
-            $this->addWidget('PiwikPro_WidgetBlogTitle', 'rssPiwikPro');
-            $this->addWidget('PiwikPro_WidgetPiwikProAd', 'promoPiwikPro');
-        }
-    }
-
-    public function rssPiwikPro()
-    {
-        try {
-            $rss = new RssRenderer('https://piwik.pro/feed/');
-            $rss->showDescription(true);
-
-            return $rss->get();
-
-        } catch (\Exception $e) {
-
-            return $this->error($e);
-        }
-    }
-
-    public function promoPiwikPro()
-    {
-        $view = new View('@PiwikPro/promoPiwikProWidget');
-
-        $promo = $this->promo->getContent();
-
-        $view->ctaLinkUrl = $this->advertising->getPromoUrlForOnPremises('PromoWidget', $promo['campaignContent']);
-        $view->ctaText = $promo['text'];
-        $view->ctaLinkTitle = $this->promo->getLinkTitle();
-
-        return $view->render();
-    }
-
-    /**
-     * @param \Exception $e
-     * @return string
-     */
-    private function error($e)
-    {
-        return '<div class="pk-emptyDataTable">'
-             . Piwik::translate('General_ErrorRequest', array('', ''))
-             . ' - ' . $e->getMessage() . '</div>';
-    }
-
-}
diff --git a/plugins/PiwikPro/config/test.php b/plugins/PiwikPro/config/test.php
deleted file mode 100644
index 327acd520568a4c774328e5330d661f1de9694d3..0000000000000000000000000000000000000000
--- a/plugins/PiwikPro/config/test.php
+++ /dev/null
@@ -1,13 +0,0 @@
-<?php
-
-use Piwik\Tests\Framework\Mock\PiwikPro\Advertising;
-use Piwik\Plugins\PiwikPro\tests\Framework\Mock\Promo;
-
-return array(
-    'Piwik\PiwikPro\Advertising' => function () {
-        return new Advertising();
-    },
-    'Piwik\Plugins\PiwikPro\Promo' => function () {
-        return new Promo();
-    }
-);
diff --git a/plugins/PiwikPro/lang/en.json b/plugins/PiwikPro/lang/en.json
deleted file mode 100644
index 34e405f8f04fcfb0443c597802e3feb5006c2a12..0000000000000000000000000000000000000000
--- a/plugins/PiwikPro/lang/en.json
+++ /dev/null
@@ -1,6 +0,0 @@
-{
-    "PiwikPro": {
-        "WidgetBlogTitle": "Piwik PRO Blog",
-        "WidgetPiwikProAd": "Piwik PRO: Advanced Analytics & Services"
-    }
-}
\ No newline at end of file
diff --git a/plugins/PiwikPro/plugin.json b/plugins/PiwikPro/plugin.json
deleted file mode 100644
index 089dd4abf204f568ce9381913a7513cccddb951b..0000000000000000000000000000000000000000
--- a/plugins/PiwikPro/plugin.json
+++ /dev/null
@@ -1,5 +0,0 @@
-{
-  "name": "PiwikPro",
-  "description": "Provides widgets to follow Piwik PRO blog and to see info about Piwik PRO services and products.",
-  "theme": false
-}
\ No newline at end of file
diff --git a/plugins/ProfessionalServices/ProfessionalServices.php b/plugins/ProfessionalServices/ProfessionalServices.php
new file mode 100644
index 0000000000000000000000000000000000000000..203c3bb6f6491715fbafa1103e63b3e6d6e76b8f
--- /dev/null
+++ b/plugins/ProfessionalServices/ProfessionalServices.php
@@ -0,0 +1,48 @@
+<?php
+/**
+ * Piwik - free/libre analytics platform
+ *
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
+ */
+
+namespace Piwik\Plugins\ProfessionalServices;
+
+class ProfessionalServices extends \Piwik\Plugin
+{
+    /**
+     * @see Piwik\Plugin::registerEvents
+     */
+    public function registerEvents()
+    {
+        return array(
+            'AssetManager.getStylesheetFiles' => 'getStylesheetFiles',
+            'Request.getRenamedModuleAndAction' => 'renameProfessionalServicesModule',
+        );
+    }
+
+    public function getStylesheetFiles(&$stylesheets)
+    {
+        $stylesheets[] = 'plugins/ProfessionalServices/stylesheets/widget.less';
+    }
+
+    /**
+     * @deprecated Can be removed in Piwik 3.0
+     * @param $module
+     * @param $action
+     */
+    public function renameProfessionalServicesModule(&$module, &$action)
+    {
+        if ($module == 'ProfessionalServices') {
+            $module = 'ProfessionalServices';
+
+            if($action == 'promoPiwikPro') {
+                $action = 'promoServices';
+            }
+
+            if($action == 'rssPiwikPro') {
+                $action = 'rss';
+            }
+        }
+    }
+}
diff --git a/plugins/PiwikPro/Promo.php b/plugins/ProfessionalServices/Promo.php
similarity index 83%
rename from plugins/PiwikPro/Promo.php
rename to plugins/ProfessionalServices/Promo.php
index c253df0f430551d92df85a7cb8a4e34a2cdab239..36f8ae155d8a4153010f2424f9372d4ff94bb630 100644
--- a/plugins/PiwikPro/Promo.php
+++ b/plugins/ProfessionalServices/Promo.php
@@ -6,7 +6,7 @@
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  */
 
-namespace Piwik\Plugins\PiwikPro;
+namespace Piwik\Plugins\ProfessionalServices;
 
 class Promo
 {
@@ -19,27 +19,27 @@ class Promo
         ),
         array(
             'campaignContent' => 'bringEnterpriseLevel',
-            'text' => 'Bring your analytics to enterprise level. Upgrade your Piwik platform and receive access to numerous premium features and assistance from our experts.'
+            'text' => 'Bring your analytics to enterprise level. Upgrade your Piwik platform and receive access to numerous premium features and assistance from experts.'
         ),
         array(
             'campaignContent' => 'funnelAnalytics',
-            'text' => 'Want Funnel Analytics? Get Premium features and enterprise-grade support from the makers of Piwik.'
+            'text' => 'Want Funnel Analytics? Get Premium features and enterprise-grade support.'
         ),
         array(
             'campaignContent' => 'monitoringAndIncident',
-            'text' => 'Do you need 24/7 Monitoring and Incident Handling for your Piwik? Get Premium features and enterprise-grade support from the makers of Piwik.'
+            'text' => 'Do you need 24/7 Monitoring and Incident Handling for your Piwik? Get Premium features and enterprise-grade support.'
         ),
         array(
             'campaignContent' => 'slowingDown',
-            'text' => 'Is your Piwik slowing down? The Piwik makers can help with your server setup!'
+            'text' => 'Is your Piwik slowing down? Piwik experts can help with your server setup!'
         ),
         array(
             'campaignContent' => 'excitingFeatures',
-            'text' => 'Want to know how to use all the exciting features in Piwik? Try our User training to be up to speed with working with Piwik.'
+            'text' => 'Want to know how to use all the exciting features in Piwik? Try a User training to be up to speed with working with Piwik.'
         ),
         array(
             'campaignContent' => 'slowingDown',
-            'text' => 'Did you know you can adjust the look and feel of Piwik to your brand, and even replace "Piwik" with your product name? Try our White Label product!',
+            'text' => 'Did you know you can adjust the look and feel of Piwik to your brand, and even replace "Piwik" with your product name? Try the White Label product!',
         ),
         array(
             'campaignContent' => 'metaSites',
diff --git a/plugins/ProfessionalServices/Widgets.php b/plugins/ProfessionalServices/Widgets.php
new file mode 100644
index 0000000000000000000000000000000000000000..b1abc5e7da722c85dfcc4100a140aeb1b2f7a667
--- /dev/null
+++ b/plugins/ProfessionalServices/Widgets.php
@@ -0,0 +1,60 @@
+<?php
+/**
+ * Piwik - free/libre analytics platform
+ *
+ * @link http://piwik.org
+ * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
+ *
+ */
+namespace Piwik\Plugins\ProfessionalServices;
+
+use Piwik\Piwik;
+use Piwik\ProfessionalServices\Advertising;
+use Piwik\Plugins\ExampleRssWidget\RssRenderer;
+use Piwik\View;
+
+class Widgets extends \Piwik\Plugin\Widgets
+{
+    protected $category = 'About Piwik';
+
+    /**
+     * @var Advertising
+     */
+    private $advertising;
+
+    /**
+     * @var Promo
+     */
+    private $promo;
+
+    public function __construct(Advertising $advertising, Promo $promo)
+    {
+        $this->advertising = $advertising;
+        $this->promo = $promo;
+    }
+
+    protected function init()
+    {
+        if ($this->advertising->areAdsForProfessionalServicesEnabled()) {
+            $this->addWidget('ProfessionalServices_WidgetProfessionalServicesForPiwik', 'promoServices');
+        }
+    }
+
+    public function rss()
+    {
+        return '';
+    }
+
+    public function promoServices()
+    {
+        $view = new View('@ProfessionalServices/promoServicesWidget');
+
+        $promo = $this->promo->getContent();
+
+        $view->ctaLinkUrl = $this->advertising->getPromoUrlForPiwikProUpgrade();
+        $view->ctaText = $promo['text'];
+        $view->ctaLinkTitle = $this->promo->getLinkTitle();
+
+        return $view->render();
+    }
+}
diff --git a/plugins/ProfessionalServices/config/test.php b/plugins/ProfessionalServices/config/test.php
new file mode 100644
index 0000000000000000000000000000000000000000..03ad8662fd90210edc118f926dc049e1d7e114c4
--- /dev/null
+++ b/plugins/ProfessionalServices/config/test.php
@@ -0,0 +1,13 @@
+<?php
+
+use Piwik\Tests\Framework\Mock\ProfessionalServices\Advertising;
+use Piwik\Plugins\ProfessionalServices\tests\Framework\Mock\Promo;
+
+return array(
+    'Piwik\ProfessionalServices\Advertising' => function () {
+        return new Advertising();
+    },
+    'Piwik\Plugins\ProfessionalServices\Promo' => function () {
+        return new Promo();
+    }
+);
diff --git a/plugins/PiwikPro/images/promo.png b/plugins/ProfessionalServices/images/promo.png
similarity index 100%
rename from plugins/PiwikPro/images/promo.png
rename to plugins/ProfessionalServices/images/promo.png
diff --git a/plugins/ProfessionalServices/lang/en.json b/plugins/ProfessionalServices/lang/en.json
new file mode 100644
index 0000000000000000000000000000000000000000..1f275d103fa2d21212aedecc357162ed9e116355
--- /dev/null
+++ b/plugins/ProfessionalServices/lang/en.json
@@ -0,0 +1,5 @@
+{
+    "ProfessionalServices": {
+        "WidgetProfessionalServicesForPiwik": "Professional Services for Piwik"
+    }
+}
\ No newline at end of file
diff --git a/plugins/ProfessionalServices/plugin.json b/plugins/ProfessionalServices/plugin.json
new file mode 100644
index 0000000000000000000000000000000000000000..852b094b3782535afa196d9419768088f2588c44
--- /dev/null
+++ b/plugins/ProfessionalServices/plugin.json
@@ -0,0 +1,4 @@
+{
+  "name": "ProfessionalServices",
+  "description": "Provides widgets to learn about Professional services and products for Piwik."
+}
\ No newline at end of file
diff --git a/plugins/PiwikPro/stylesheets/widget.less b/plugins/ProfessionalServices/stylesheets/widget.less
similarity index 100%
rename from plugins/PiwikPro/stylesheets/widget.less
rename to plugins/ProfessionalServices/stylesheets/widget.less
diff --git a/plugins/PiwikPro/templates/promoPiwikProWidget.twig b/plugins/ProfessionalServices/templates/promoServicesWidget.twig
similarity index 79%
rename from plugins/PiwikPro/templates/promoPiwikProWidget.twig
rename to plugins/ProfessionalServices/templates/promoServicesWidget.twig
index 2864fa340f19925d6d1ed832d16a97e7cff185ef..67f87df40a788ad3915f87396ad86bc8726019b9 100644
--- a/plugins/PiwikPro/templates/promoPiwikProWidget.twig
+++ b/plugins/ProfessionalServices/templates/promoServicesWidget.twig
@@ -1,6 +1,6 @@
 <div class="promoWidget">
     <div class="promo">
-        <img class="icon" src="plugins/PiwikPro/images/promo.png">
+        <img class="icon" src="plugins/ProfessionalServices/images/promo.png">
         <p class="text">
             {{ ctaText }}
             <br /><br />
diff --git a/plugins/PiwikPro/tests/Framework/Mock/Promo.php b/plugins/ProfessionalServices/tests/Framework/Mock/Promo.php
similarity index 71%
rename from plugins/PiwikPro/tests/Framework/Mock/Promo.php
rename to plugins/ProfessionalServices/tests/Framework/Mock/Promo.php
index 47dd6f6497a0b9ac86222b889590c0c1cd531818..a854b9da8ab159e79fc9d9fa786acc467807168a 100644
--- a/plugins/PiwikPro/tests/Framework/Mock/Promo.php
+++ b/plugins/ProfessionalServices/tests/Framework/Mock/Promo.php
@@ -6,9 +6,9 @@
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  */
 
-namespace Piwik\Plugins\PiwikPro\tests\Framework\Mock;
+namespace Piwik\Plugins\ProfessionalServices\tests\Framework\Mock;
 
-class Promo extends \Piwik\Plugins\PiwikPro\Promo
+class Promo extends \Piwik\Plugins\ProfessionalServices\Promo
 {
     public function getLinkTitle()
     {
diff --git a/plugins/Referrers/tests/Integration/Columns/ReferrerKeywordTest.php b/plugins/Referrers/tests/Integration/Columns/ReferrerKeywordTest.php
index f5ff10e11c4315bcdec64d2fe68b5936368eabc5..1e7e4af8cb626befcc8b7a1989d91cc786f4c4bd 100644
--- a/plugins/Referrers/tests/Integration/Columns/ReferrerKeywordTest.php
+++ b/plugins/Referrers/tests/Integration/Columns/ReferrerKeywordTest.php
@@ -38,7 +38,7 @@ class ReferrerKeywordTest extends IntegrationTestCase
         $ecommerce = false;
 
         Fixture::createWebsite($date, $ecommerce, $name = 'test1', $url = 'http://piwik.org/');
-        Fixture::createWebsite($date, $ecommerce, $name = 'test3', $url = 'http://piwik.pro/');
+        Fixture::createWebsite($date, $ecommerce, $name = 'test3', $url = 'http://piwik.xyz/');
 
         $this->keyword = new Keyword();
     }
diff --git a/plugins/Referrers/tests/Integration/Columns/ReferrerNameTest.php b/plugins/Referrers/tests/Integration/Columns/ReferrerNameTest.php
index f118e14ba6e2809eec9b6b40caf706a692cf9238..cd1610a178428a4cfd6ee3075297011c85f6d05e 100644
--- a/plugins/Referrers/tests/Integration/Columns/ReferrerNameTest.php
+++ b/plugins/Referrers/tests/Integration/Columns/ReferrerNameTest.php
@@ -44,7 +44,7 @@ class ReferrerNameTest extends IntegrationTestCase
 
         Fixture::createWebsite($date, $ecommerce, $name = 'test1', $url = 'http://piwik.org/foo/bar');
         Fixture::createWebsite($date, $ecommerce, $name = 'test2', $url = 'http://piwik.org/');
-        Fixture::createWebsite($date, $ecommerce, $name = 'test3', $url = 'http://piwik.pro/');
+        Fixture::createWebsite($date, $ecommerce, $name = 'test3', $url = 'http://piwik.xyz/');
 
         $this->referrerName = new ReferrerName();
     }
diff --git a/plugins/Referrers/tests/Integration/Columns/ReferrerTypeTest.php b/plugins/Referrers/tests/Integration/Columns/ReferrerTypeTest.php
index 7b4b30426235b2ba341729676aec7d35d96bab5f..63da107af57b5a7e7d7a851ec6be8830e454a0e0 100644
--- a/plugins/Referrers/tests/Integration/Columns/ReferrerTypeTest.php
+++ b/plugins/Referrers/tests/Integration/Columns/ReferrerTypeTest.php
@@ -45,7 +45,7 @@ class ReferrerTypeTest extends IntegrationTestCase
 
         Fixture::createWebsite($date, $ecommerce, $name = 'test1', $url = 'http://piwik.org/foo/bar');
         Fixture::createWebsite($date, $ecommerce, $name = 'test2', $url = 'http://piwik.org/');
-        Fixture::createWebsite($date, $ecommerce, $name = 'test3', $url = 'http://piwik.pro/');
+        Fixture::createWebsite($date, $ecommerce, $name = 'test3', $url = 'http://piwik.xyz/');
         Fixture::createWebsite($date, $ecommerce, $name = 'test4', $url = 'http://google.com/subdir/', 1, null, null, null, null, $excludeUnknownUrls = 1);
 
         $this->referrerType = new ReferrerType();
diff --git a/plugins/Widgetize/tests/System/WidgetTest.php b/plugins/Widgetize/tests/System/WidgetTest.php
index fe126b0b08e8ab245f7b21a7b42a8dffa9f86115..c73ebf25e65100ad7ac04f313382e2199232ee4d 100644
--- a/plugins/Widgetize/tests/System/WidgetTest.php
+++ b/plugins/Widgetize/tests/System/WidgetTest.php
@@ -836,21 +836,12 @@ class WidgetTest extends SystemTestCase
                         ),
                 ),
                 array (
-                    'name' => 'Piwik PRO Blog',
-                    'uniqueId' => 'widgetPiwikProrssPiwikPro',
+                    'name' => 'Professional Services for Piwik',
+                    'uniqueId' => 'widgetProfessionalServicespromoServices',
                     'parameters' =>
                         array (
-                            'module' => 'PiwikPro',
-                            'action' => 'rssPiwikPro',
-                        ),
-                ),
-                array (
-                    'name' => 'Piwik PRO: Advanced Analytics & Services',
-                    'uniqueId' => 'widgetPiwikPropromoPiwikProPiwikPro',
-                    'parameters' =>
-                        array (
-                            'module' => 'PiwikPro',
-                            'action' => 'promoPiwikPro',
+                            'module' => 'ProfessionalServices',
+                            'action' => 'promoServices',
                         ),
                 )
         );
diff --git a/tests/PHPUnit/Fixtures/UITestFixture.php b/tests/PHPUnit/Fixtures/UITestFixture.php
index a0201dcbbbeba718c255b4aa00873e56f449165f..1fd3b0405d6d78c26415830b1cea88685e658b66 100644
--- a/tests/PHPUnit/Fixtures/UITestFixture.php
+++ b/tests/PHPUnit/Fixtures/UITestFixture.php
@@ -254,7 +254,6 @@ class UITestFixture extends SqlDump
                 || $widget['uniqueId'] == 'widgetReferrersgetKeywordsForPage'
                 || $widget['uniqueId'] == 'widgetLivegetVisitorProfilePopup'
                 || $widget['uniqueId'] == 'widgetActionsgetPageTitles'
-                || $widget['uniqueId'] == 'widgetPiwikProrssPiwikPro'
                 || strpos($widget['uniqueId'], 'widgetExample') === 0
             ) {
                 continue;
diff --git a/tests/PHPUnit/Framework/Mock/PiwikPro/Advertising.php b/tests/PHPUnit/Framework/Mock/ProfessionalServices/Advertising.php
similarity index 56%
rename from tests/PHPUnit/Framework/Mock/PiwikPro/Advertising.php
rename to tests/PHPUnit/Framework/Mock/ProfessionalServices/Advertising.php
index b1de8c4899c75f6c635ce9405a25ec6dbb76287b..4be42a6deb43cd0cff3fc5c7e2bdc22881b6b487 100644
--- a/tests/PHPUnit/Framework/Mock/PiwikPro/Advertising.php
+++ b/tests/PHPUnit/Framework/Mock/ProfessionalServices/Advertising.php
@@ -5,15 +5,15 @@
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  */
-namespace Piwik\Tests\Framework\Mock\PiwikPro;
+namespace Piwik\Tests\Framework\Mock\ProfessionalServices;
 
-class Advertising extends \Piwik\PiwikPro\Advertising
+class Advertising extends \Piwik\ProfessionalServices\Advertising
 {
     public function __construct()
     {
     }
 
-    public function arePiwikProAdsEnabled()
+    public function areAdsForProfessionalServicesEnabled()
     {
         return true;
     }
diff --git a/tests/PHPUnit/Integration/PiwikPro/AdvertisingTest.php b/tests/PHPUnit/Integration/ProfessionalSupport/AdvertisingTest.php
similarity index 50%
rename from tests/PHPUnit/Integration/PiwikPro/AdvertisingTest.php
rename to tests/PHPUnit/Integration/ProfessionalSupport/AdvertisingTest.php
index 5d3c9c27d0f39c6749ec58e9b516755ab44ac4de..d8f728d0516a5f3cf65715b3ad72747670d1f2db 100644
--- a/tests/PHPUnit/Integration/PiwikPro/AdvertisingTest.php
+++ b/tests/PHPUnit/Integration/ProfessionalSupport/AdvertisingTest.php
@@ -6,17 +6,17 @@
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  */
 
-namespace Piwik\Tests\Integration\PiwikPro;
+namespace Piwik\Tests\Integration\ProfessionalServices;
 
 use Piwik\Config;
-use Piwik\PiwikPro\Advertising;
+use Piwik\ProfessionalServices\Advertising;
 use Piwik\Plugin;
 use Piwik\Tests\Framework\Mock\FakeConfig;
 use Piwik\Tests\Framework\Mock\Plugin\Manager;
 use Piwik\Tests\Framework\TestCase\IntegrationTestCase;
 
 /**
- * @group PiwikPro
+ * @group ProfessionalServices
  * @group Advertising
  * @group Integration
  */
@@ -37,87 +37,54 @@ class AdvertisingTest extends IntegrationTestCase
      */
     private $pluginManager;
 
-    private $exampleUrl = 'https://piwik.pro/test';
+    private $exampleUrl = 'https://piwik.xyz/test';
 
     public function setUp()
     {
-        $this->config = new FakeConfig(array('General' => array('piwik_pro_ads_enabled' => '1')));
+        $this->config = new FakeConfig(array('General' => array('piwik_professional_support_ads_enabled' => '1')));
         $this->pluginManager = new Manager();
 
         $this->advertising = $this->buildAdvertising($this->config);
     }
 
-    public function test_arePiwikProAdsEnabled_ActuallyEnabled()
+    public function test_areAdsForProfessionalServicesEnabled_ActuallyEnabled()
     {
-        $enabled = $this->advertising->arePiwikProAdsEnabled();
+        $enabled = $this->advertising->areAdsForProfessionalServicesEnabled();
 
         $this->assertTrue($enabled);
     }
 
-    public function test_arePiwikProAdsEnabled_Disabled()
+    public function test_areAdsForProfessionalServicesEnabled_Disabled()
     {
-        $this->config->General = array('piwik_pro_ads_enabled' => '0');
+        $this->config->General = array('piwik_professional_support_ads_enabled' => '0');
 
-        $enabled = $this->advertising->arePiwikProAdsEnabled();
+        $enabled = $this->advertising->areAdsForProfessionalServicesEnabled();
 
         $this->assertFalse($enabled);
     }
 
-    public function test_arePiwikProAdsEnabled_shouldBeDisabledWhenCloudPluginIsInstalled()
+    public function test_areAdsForProfessionalServicesEnabled_UsingPreviousSettingName()
     {
-        $enabled = $this->advertising->arePiwikProAdsEnabled();
-        $this->assertTrue($enabled);
-
-        $this->pluginManager->setActivatedPlugins(array('CloudAdmin'));
+        $this->config->General = array('piwik_pro_ads_enabled' => '1');
 
-        $enabled = $this->advertising->arePiwikProAdsEnabled();
-        $this->assertFalse($enabled);
-    }
+        $enabled = $this->advertising->areAdsForProfessionalServicesEnabled();
 
-    public function test_arePiwikProAdsEnabled_shouldBeDisabledWhenEnterprisePluginIsInstalled()
-    {
-        $enabled = $this->advertising->arePiwikProAdsEnabled();
         $this->assertTrue($enabled);
-
-        $this->pluginManager->setActivatedPlugins(array('EnterpriseAdmin'));
-
-        $enabled = $this->advertising->arePiwikProAdsEnabled();
-        $this->assertFalse($enabled);
     }
 
+
     public function test_shouldBeEnabledByDefault()
     {
         $enabled = $this->buildAdvertising(Config::getInstance());
 
-        $this->assertTrue($enabled->arePiwikProAdsEnabled());
+        $this->assertTrue($enabled->areAdsForProfessionalServicesEnabled());
     }
 
     public function test_getPromoUrlForOnPremises_WithoutContent()
     {
-        $link = $this->advertising->getPromoUrlForOnPremises('Installation_End');
-
-        $this->assertSame('https://piwik.pro/c/upgrade/?pk_campaign=Upgrade_to_Pro&pk_medium=Installation_End&pk_source=Piwik_App', $link);
-    }
-
-    public function test_getPromoUrlForOnPremises_WithContent()
-    {
-        $link = $this->advertising->getPromoUrlForOnPremises('Installation_End', 'TestContent');
-
-        $this->assertSame('https://piwik.pro/c/upgrade/?pk_campaign=Upgrade_to_Pro&pk_medium=Installation_End&pk_source=Piwik_App&pk_content=TestContent', $link);
-    }
-
-    public function test_getPromoUrlForCloud_WithoutContent()
-    {
-        $link = $this->advertising->getPromoUrlForCloud('Installation_End');
-
-        $this->assertSame('https://piwik.pro/cloud/?pk_campaign=Upgrade_to_Cloud&pk_medium=Installation_End&pk_source=Piwik_App', $link);
-    }
-
-    public function test_getPromoUrlForCloud_WithContent()
-    {
-        $link = $this->advertising->getPromoUrlForCloud('Installation_End', 'TestContent');
+        $link = $this->advertising->getPromoUrlForPiwikProUpgrade();
 
-        $this->assertSame('https://piwik.pro/cloud/?pk_campaign=Upgrade_to_Cloud&pk_medium=Installation_End&pk_source=Piwik_App&pk_content=TestContent', $link);
+        $this->assertSame('https://piwik.org/recommends/piwik-pro-from-app', $link);
     }
 
     public function test_addPromoCampaignParametersToUrl_withoutContentWithoutQuery()
diff --git a/tests/PHPUnit/Integration/WidgetsListTest.php b/tests/PHPUnit/Integration/WidgetsListTest.php
index 845407cb4ee306651f5188f75aa0bfd366dab936..586a23b7491218a84b0dfc28d857d41d3f27a0d4 100644
--- a/tests/PHPUnit/Integration/WidgetsListTest.php
+++ b/tests/PHPUnit/Integration/WidgetsListTest.php
@@ -46,7 +46,7 @@ class WidgetsListTest extends IntegrationTestCase
             'Referrers_Referrers'          => 7,
             'Goals_Goals'                  => 1,
             'SEO'                          => 2,
-            'About Piwik'                  => 6,
+            'About Piwik'                  => 5,
             'DevicesDetection_DevicesDetection' => 8,
             'Insights_WidgetCategory' => 2
         );
diff --git a/tests/UI/expected-ui-screenshots b/tests/UI/expected-ui-screenshots
index e18616b9c745778a543725e5cb8a15beaa1dcc12..11c9ec5af3fc5a180cae5e39bc952535aa3f732e 160000
--- a/tests/UI/expected-ui-screenshots
+++ b/tests/UI/expected-ui-screenshots
@@ -1 +1 @@
-Subproject commit e18616b9c745778a543725e5cb8a15beaa1dcc12
+Subproject commit 11c9ec5af3fc5a180cae5e39bc952535aa3f732e
diff --git a/tests/UI/specs/Installation_spec.js b/tests/UI/specs/Installation_spec.js
index 2ee77adfeccd2e0038770e2032281fb3a1542b3f..3ddfdc3587dc10ea0e8a7e24df19cde2757053aa 100644
--- a/tests/UI/specs/Installation_spec.js
+++ b/tests/UI/specs/Installation_spec.js
@@ -88,7 +88,7 @@ describe("Installation", function () {
 
     var pageUrl, pageUrlDe;
 
-    it("should show Piwik PRO GmbH when language is German", function (done) {
+    it("should un-select Professional Services newsletter checkbox when language is German", function (done) {
         expect.screenshot("superuser_de").to.be.capture(function (page) {
             pageUrl = page.getCurrentUrl();
             pageUrlDe = pageUrl + '&language=de'
diff --git a/tests/javascript/index.php b/tests/javascript/index.php
index eea3ffac9603558bf971ca05707a46b413444eac..043a9ef8c19e8d1d3ae109ab1cbd9a7589675075 100644
--- a/tests/javascript/index.php
+++ b/tests/javascript/index.php
@@ -2487,9 +2487,9 @@ function PiwikTest() {
         }
 
         // multiple paths / domains
-        tracker.setDomains( ['piwik.org/path', 'piwik.org/foo', 'piwik.org/bar/baz', '.piwik.pro/test'] );
-        ok( isSiteHostPath('piwik.pro', 'test/bar'), 'isSiteHostPath("piwik.pro", "test/bar")' );
-        ok( isSiteHostPath('piwik.pro', '/test/bar'), 'isSiteHostPath("piwik.pro", "/test/bar")' );
+        tracker.setDomains( ['piwik.org/path', 'piwik.org/foo', 'piwik.org/bar/baz', '.piwik.xyz/test'] );
+        ok( isSiteHostPath('piwik.xyz', 'test/bar'), 'isSiteHostPath("piwik.xyz", "test/bar")' );
+        ok( isSiteHostPath('piwik.xyz', '/test/bar'), 'isSiteHostPath("piwik.xyz", "/test/bar")' );
         ok( !isSiteHostPath('piwik.org', '/foobar/'), 'isSiteHostPath("piwik.org", "/foobar/")' );
         ok( !isSiteHostPath('piwik.org', 'foobar/'), 'isSiteHostPath("piwik.org", "foobar/")' );
         ok( !isSiteHostPath('piwik.org', 'foobar'), 'isSiteHostPath("piwik.org", "foobar")' );
@@ -2498,12 +2498,12 @@ function PiwikTest() {
         ok( !isSiteHostPath('piwik.org', '/bar/ba'), 'isSiteHostPath("piwik.org", "/bar/ba")' );
         ok( isSiteHostPath('piwik.org', '/path/test'), 'isSiteHostPath("piwik.org", "/path/test")' );
         ok( isSiteHostPath('piwik.org', '/path/test.htm'), 'isSiteHostPath("piwik.org", "/path/test.htm")' );
-        ok( isSiteHostPath('dev.piwik.pro', '/test'), 'isSiteHostPath("dev.piwik.pro", "/test")' );
-        ok( !isSiteHostPath('dev.piwik.pro', 'something/test.htm'), 'isSiteHostPath("dev.piwik.pro", "something/test")' );
-        ok( !isSiteHostPath('dev.piwik.pro', '/'), 'isSiteHostPath("dev.piwik.pro", "/")' );
-        ok( !isSiteHostPath('dev.piwik.pro', ''), 'isSiteHostPath("dev.piwik.pro", "")' );
+        ok( isSiteHostPath('dev.piwik.xyz', '/test'), 'isSiteHostPath("dev.piwik.xyz", "/test")' );
+        ok( !isSiteHostPath('dev.piwik.xyz', 'something/test.htm'), 'isSiteHostPath("dev.piwik.xyz", "something/test")' );
+        ok( !isSiteHostPath('dev.piwik.xyz', '/'), 'isSiteHostPath("dev.piwik.xyz", "/")' );
+        ok( !isSiteHostPath('dev.piwik.xyz', ''), 'isSiteHostPath("dev.piwik.xyz", "")' );
         ok( !isSiteHostPath('piwik.org', '/'), 'isSiteHostPath("piwik.org", "/")' );
-        ok( !isSiteHostPath('piwik.pro', '/'), 'isSiteHostPath("piwik.pro", "/")' );
+        ok( !isSiteHostPath('piwik.xyz', '/'), 'isSiteHostPath("piwik.xyz", "/")' );
         ok( !isSiteHostPath('piwik.org', '/index.htm'), 'isSiteHostPath("piwik.org", "/index.htm")' );
         ok( !isSiteHostPath('piwik.org', '/anythingelse'), 'isSiteHostPath("piwik.org", "/anythingelse")' );
         ok( !isSiteHostPath('another.org', '/'), 'isSiteHostPath("another.org", "/")' );
@@ -2541,7 +2541,7 @@ function PiwikTest() {
             return link;
         }
 
-        tracker.setDomains( ['.piwik.org/path', '.piwik.org/foo', '.piwik.org/bar/baz', '.piwik.pro/test'] );
+        tracker.setDomains( ['.piwik.org/path', '.piwik.org/foo', '.piwik.org/bar/baz', '.piwik.xyz/test'] );
 
         // they should not be detected as outlink as they match one of the domains
         equal(undefined, getLinkIfShouldBeProcessed(createLink('http://www.piwik.org/foo/bar')), 'getLinkIfShouldBeProcessed http://www.piwik.org/foo/bar matches .piwik.org/foo')
@@ -2569,9 +2569,9 @@ function PiwikTest() {
             "type": "download"
         }, getLinkIfShouldBeProcessed(createLink('http://www.piwik.com/foobar/download.apk')), 'getLinkIfShouldBeProcessed should detect download even if it goes to different domain')
         propEqual({
-            "href": "http://www.piwik.pro/foo/",
+            "href": "http://www.piwik.xyz/foo/",
             "type": "link"
-        }, getLinkIfShouldBeProcessed(createLink('http://www.piwik.pro/foo/')), 'getLinkIfShouldBeProcessed path matches but domain not so outlink')
+        }, getLinkIfShouldBeProcessed(createLink('http://www.piwik.xyz/foo/')), 'getLinkIfShouldBeProcessed path matches but domain not so outlink')
         propEqual({
             "href": "http://www.piwik.org/bar",
             "type": "link"
diff --git a/core/PiwikPro/Advertising.php b/core/ProfessionalServices/Advertising.php
similarity index 56%
rename from core/PiwikPro/Advertising.php
rename to core/ProfessionalServices/Advertising.php
index f2c47f58c2d2f8efc84f038bba7572ec9d60886a..07e42c46e4c49d34355968c2e3dd5cef5c17c781 100644
--- a/core/PiwikPro/Advertising.php
+++ b/core/ProfessionalServices/Advertising.php
@@ -5,22 +5,21 @@
  * @link http://piwik.org
  * @license http://www.gnu.org/licenses/gpl-3.0.html GPL v3 or later
  */
-namespace Piwik\PiwikPro;
+namespace Piwik\ProfessionalServices;
 
 use Piwik\Plugin;
 use Piwik\Config;
 
 /**
  * Piwik PRO Advertising related methods. Lets you for example check whether advertising is enabled, generate
  * links for different landing pages etc.
  *
- * @api
  * @since 2.16.0
  */
 class Advertising
 {
-    const CAMPAIGN_NAME_UPGRADE_TO_PRO = 'Upgrade_to_Pro';
-    const CAMPAIGN_NAME_UPGRADE_TO_CLOUD = 'Upgrade_to_Cloud';
+    const CAMPAIGN_NAME_PROFESSIONAL_SERVICES = 'App_ProfessionalServices';
 
     /**
      * @var Plugin\Manager
@@ -39,36 +38,27 @@ class Advertising
     }
 
     /**
-     * Returns true if it is ok to show some Piwik PRO advertising in the Piwik UI.
+     * Returns true if it is ok to show some advertising in the Piwik UI.
      * @return bool
      */
-    public function arePiwikProAdsEnabled()
+    public function areAdsForProfessionalServicesEnabled()
     {
-        if ($this->pluginManager->isPluginActivated('EnterpriseAdmin')
-            || $this->pluginManager->isPluginActivated('LoginAdmin')
-            || $this->pluginManager->isPluginActivated('CloudAdmin')
-            || $this->pluginManager->isPluginActivated('WhiteLabel')) {
-            return false;
-        }
-
-        $showAds = $this->config->General['piwik_pro_ads_enabled'];
-
-        return !empty($showAds);
+        return $this->isAdsEnabledInConfig($this->config->General);
     }
 
     /**
      * Get URL for promoting the Piwik Cloud.
      *
      * @param string $campaignMedium
      * @param string $campaignContent
      * @return string
      */
-    public function getPromoUrlForCloud($campaignMedium, $campaignContent = '')
+    public function getPromoUrlForProfessionalServices($campaignMedium, $campaignContent = '')
     {
-        $url = 'https://piwik.pro/cloud/?';
+        $url = 'https://piwik.org/consulting/?';
 
         $campaign = $this->getCampaignParametersForPromoUrl(
-            $name = self::CAMPAIGN_NAME_UPGRADE_TO_CLOUD,
+            $name = self::CAMPAIGN_NAME_PROFESSIONAL_SERVICES,
             $campaignMedium,
             $campaignContent
         );
@@ -77,26 +67,18 @@ class Advertising
     }
 
     /**
-     * Get URL for promoting Piwik On Premises.
-     * @param string $campaignMedium
-     * @param string $campaignContent
+     * Get URL for letting people know about upgrade to On premises
+     *
      * @return string
      */
-    public function getPromoUrlForOnPremises($campaignMedium, $campaignContent = '')
+    public function getPromoUrlForPiwikProUpgrade()
     {
-        $url = 'https://piwik.pro/c/upgrade/?';
-
-        $campaign = $this->getCampaignParametersForPromoUrl(
-            $name = self::CAMPAIGN_NAME_UPGRADE_TO_PRO,
-            $campaignMedium,
-            $campaignContent
-        );
-
-        return $url . $campaign;
+        return 'https://piwik.org/recommends/piwik-pro-from-app';
     }
 
     /**
      * Appends campaign parameters to the given URL for promoting any Piwik PRO service.
      * @param string $url
      * @param string $campaignName
      * @param string $campaignMedium
@@ -121,7 +103,7 @@ class Advertising
     }
 
     /**
      * Generates campaign URL parameters that can be used with any promotion link for Piwik PRO.
      *
      * @param string $campaignName
      * @param string $campaignMedium
@@ -138,4 +120,15 @@ class Advertising
 
         return $campaignName;
     }
+
+    /**
+     * @param $configGeneralSection
+     * @return bool
+     */
+    public static function isAdsEnabledInConfig($configGeneralSection)
+    {
+        $oldSettingValue = @$configGeneralSection['piwik_pro_ads_enabled'];
+        $newSettingValue = @$configGeneralSection['piwik_professional_support_ads_enabled'];
+        return (bool) ($newSettingValue || $oldSettingValue);
+    }
 }
@@ -5,22 +5,21 @@
 
 /**
- * Piwik PRO Advertising related methods. Lets you for example check whether advertising is enabled, generate
- * links for different landing pages etc.
+ * Advertising for providers of Professional Support for Piwik.
+ *
+ * Lets you for example check whether advertising is enabled, generate links for different landing pages etc.
  *
@@ -39,36 +38,27 @@ class Advertising
 
     /**
-     * Get URL for promoting the Piwik Cloud.
+     * Get URL for promoting Professional Services for Piwik
      *
      * @param string $campaignMedium
@@ -77,26 +67,18 @@ class Advertising
 
     /**
-     * Appends campaign parameters to the given URL for promoting any Piwik PRO service.
+     * Appends campaign parameters to the given URL for promoting any Professional Support for Piwik service.
+     *
      * @param string $url
      * @param string $campaignName
@@ -121,7 +103,7 @@ class Advertising
 
     /**
-     * Generates campaign URL parameters that can be used with any promotion link for Piwik PRO.
+     * Generates campaign URL parameters that can be used with promoting Professional Support service.
      *
      * @param string $campaignName
diff --git a/core/View.php b/core/View.php
index 08beba40b848bcc11c1ba323ef918399cdd4e650..0a2cbabb67a9bea507b7ca6a6dc33068227f0ef9 100644
--- a/core/View.php
+++ b/core/View.php
@@ -86,7 +86,7 @@ if (!defined('PIWIK_USER_PATH')) {
  *                  which is outputted in the template, eg, `{{ postEvent('MyPlugin.event') }}`
  * - **isPluginLoaded**: Returns true if the supplied plugin is loaded, false if otherwise.
  *                       `{% if isPluginLoaded('Goals') %}...{% endif %}`
  * - **arePiwikProAdsEnabled**: Returns true if it is ok to show some Piwik PRO advertising in the UI (from Piwik 2.16.0)
  *
  * ### Examples
  *
@@ -229,8 +229,8 @@ class View implements ViewInterface
             $this->disableLink = Common::getRequestVar('disableLink', 0, 'int');
             $this->isWidget = Common::getRequestVar('widget', 0, 'int');
 
-            $piwikProAds = StaticContainer::get('Piwik\PiwikPro\Advertising');
-            $this->arePiwikProAdsEnabled = $piwikProAds->arePiwikProAdsEnabled();
+            $piwikAds = StaticContainer::get('Piwik\ProfessionalServices\Advertising');
+            $this->areAdsForProfessionalServicesEnabled = $piwikAds->areAdsForProfessionalServicesEnabled();
 
             if (Development::isEnabled()) {
                 $cacheBuster = rand(0, 10000);
@@ -86,7 +86,7 @@ if (!defined('PIWIK_USER_PATH')) {
  * - **isPluginLoaded**: Returns true if the supplied plugin is loaded, false if otherwise.
  *                       `{% if isPluginLoaded('Goals') %}...{% endif %}`
- * - **arePiwikProAdsEnabled**: Returns true if it is ok to show some Piwik PRO advertising in the UI (from Piwik 2.16.0)
+ * - **areAdsForProfessionalServicesEnabled**: Returns true if it is ok to show some advertising in the UI for providers of Professional Support for Piwik (from Piwik 2.16.0)
  *
  * ### Examples